package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WorkOrderFjMapper;
import com.ruoyi.system.domain.WorkOrderFj;
import com.ruoyi.system.service.IWorkOrderFjService;

/**
 * 工单_附件Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-12
 */
@Service
public class WorkOrderFjServiceImpl implements IWorkOrderFjService 
{
    @Autowired
    private WorkOrderFjMapper workOrderFjMapper;

    /**
     * 查询工单_附件
     * 
     * @param id 工单_附件主键
     * @return 工单_附件
     */
    @Override
    public WorkOrderFj selectWorkOrderFjById(Long id)
    {
        return workOrderFjMapper.selectWorkOrderFjById(id);
    }

    /**
     * 查询工单_附件列表
     * 
     * @param workOrderFj 工单_附件
     * @return 工单_附件
     */
    @Override
    public List<WorkOrderFj> selectWorkOrderFjList(WorkOrderFj workOrderFj)
    {
        return workOrderFjMapper.selectWorkOrderFjList(workOrderFj);
    }

    /**
     * 新增工单_附件
     * 
     * @param workOrderFj 工单_附件
     * @return 结果
     */
    @Override
    public int insertWorkOrderFj(WorkOrderFj workOrderFj)
    {
        return workOrderFjMapper.insertWorkOrderFj(workOrderFj);
    }

    /**
     * 修改工单_附件
     * 
     * @param workOrderFj 工单_附件
     * @return 结果
     */
    @Override
    public int updateWorkOrderFj(WorkOrderFj workOrderFj)
    {
        return workOrderFjMapper.updateWorkOrderFj(workOrderFj);
    }

    /**
     * 批量删除工单_附件
     * 
     * @param ids 需要删除的工单_附件主键
     * @return 结果
     */
    @Override
    public int deleteWorkOrderFjByIds(Long[] ids)
    {
        return workOrderFjMapper.deleteWorkOrderFjByIds(ids);
    }

    /**
     * 删除工单_附件信息
     * 
     * @param id 工单_附件主键
     * @return 结果
     */
    @Override
    public int deleteWorkOrderFjById(Long id)
    {
        return workOrderFjMapper.deleteWorkOrderFjById(id);
    }
}
